@@ -23,7 +23,7 @@
 #include <linux/netdevice.h>
 #include <linux/etherdevice.h>
 #include <linux/mm.h>
-#include <linux/skbuff.h>
+#include "compat_skbuff.h"
 #include <linux/if_ether.h>
 #include <linux/sockios.h>
 #include "compat_sock.h"
