@@ -18,7 +18,7 @@
 
 #include <linux/netdevice.h>
 #include <linux/etherdevice.h>
-#include <linux/skbuff.h>
+#include "compat_skbuff.h"
 #include <linux/if_ether.h>
 #include <linux/sockios.h>
 #include "compat_sock.h"
@@ -622,18 +622,18 @@ VNetCopyDatagramToUser(const struct sk_buff *skb,	// IN
 #else
    /*
     * If truncation occurs, we do not bother with checksumming - caller cannot
-    * verify checksum anyway in such case, and copy without checksum it is
+    * verify checksum anyway in such case, and copy without checksum is
     * faster.
     */
    if (skb->pkt_type == PACKET_OUTGOING && 	/* Packet must be outgoing */
        skb->ip_summed == VM_CHECKSUM_PARTIAL &&	/* Without checksum */
-       skb->h.raw != skb->nh.raw &&		/* We must know where header is */
+       compat_skb_network_header_len(skb) &&    /* We must know where header is */
        skb->len == count) {			/* No truncation may occur */
       size_t skl;
       int csum;
       u_int16_t csum16;
-      
-      skl = skb->h.raw - skb->data;
+     
+      skl = compat_skb_csum_start(skb);
       if (VNetCopyDatagram(skb, buf, skl)) {
 	 return -EFAULT;
       }
@@ -642,7 +642,8 @@ VNetCopyDatagramToUser(const struct sk_buff *skb,	// IN
 	 return csum;
       }
       csum16 = csum;
-      if (copy_to_user(buf + skl + skb->csum, &csum16, sizeof csum16)) {
+      if (copy_to_user(buf + skl + compat_skb_csum_offset(skb),
+                       &csum16, sizeof csum16)) {
 	 return -EFAULT;
       }
    } else {
